@@ -19,10 +19,13 @@ redact_port <- function(snapshot) {
 }
 
 expect_api_routes <- function(routes) {
-    testthat::expect_equal(names(routes), c("metadata", "ping", "predict"))
+    testthat::expect_equal(
+        names(routes),
+        c("metadata", "ping", "predict", "prototype")
+    )
     testthat::expect_equal(
         map_chr(routes, "verbs"),
-        c(metadata = "GET", ping = "GET", predict = "POST")
+        c(metadata = "GET", ping = "GET", predict = "POST", prototype = "GET")
     )
 }
 
